#
# spec file for package perl-Devel-PPPort
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Devel-PPPort
Version:        3.42
Release:        lp150.1.1
%define cpan_name Devel-PPPort
Summary:        Perl/Pollution/Portability
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Devel-PPPort/
Source0:        https://cpan.metacpan.org/authors/id/X/XS/XSAWYERX/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
Perl's API has changed over time, gaining new features, new functions,
increasing its flexibility, and reducing the impact on the C namespace
environment (reduced pollution). The header file written by this module,
typically _ppport.h_, attempts to bring some of the newer Perl API features
to older versions of Perl, so that you can worry less about keeping track
of old releases, but users can still reap the benefit.

'Devel::PPPort' contains two functions, 'WriteFile' and 'GetFileContents'.
'WriteFile''s only purpose is to write the _ppport.h_ C header file. This
file contains a series of macros and, if explicitly requested, functions
that allow XS modules to be built using older versions of Perl. Currently,
Perl versions from 5.003 to 5.20 are supported.

'GetFileContents' can be used to retrieve the file contents rather than
writing it out.

This module is used by 'h2xs' to write the file _ppport.h_.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes HACKERS soak

%changelog
* Sun Apr 22 2018 coolo@suse.com
- updated to 3.42
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.42 - 2018-04-21
  * Include 'Changes' (this file) in the distribution.
  3.41 - 2018-04-21
  * Fix security problem: CWE-134: Use of Externally-Controlled Format String.
  * Fix WIDEST_UTYPE.
  * Add the following functions:
    croak_sv, die_sv, mess_sv, warn_sv, mess, vmess, warn_nocontext,
    croak_nocontext, croak_no_modify, croak_memory_wrap, croak_xs_usage.
  * Delist functions listed as deprecated or unstable.
  * (perl #132876) define API macros on if the NEED_ macro is defined.
  * (perl #132876) only define croak_xs_usage()'s assert macro if cxu requested.
  * (perl #132761) updates for older perls.
  * Do not define PERL_MAGIC_qr more times.
  * Do not mask Perl_warn_nocontext and Perl_croak_nocontext.
    (Fixes compile errors on older threaded Perl versions.)
  * Skip ASCII tests on non-ASCII platforms.
  * Skip tests invalid on EBCDIC.
  * Will now compile under C++11.
  * Documentation improvements.
* Tue May 16 2017 coolo@suse.com
- updated to 3.36
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.36 - 2017-05-14
  * Support Perl 5.26.* which no longer has '.' in @INC
* Fri Jun 24 2016 coolo@suse.com
- updated to 3.35
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.35 - 2016-06-17
  * Fix compilation in bleadperl by removing a bad test.
* Mon Jun 13 2016 coolo@suse.com
- updated to 3.34
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.34 - 2016-06-04
  * Fix compilation on Windows with certain compilers.
    (__attribute__ not recognized. (#GH 36)
* Sun Jun 12 2016 coolo@suse.com
- updated to 3.33
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.33 - 2016-06-03
  * Add PERL_OP_PARENT related macros, and cBOOL
  * Add SvRXOK/SvRX/PERL_MAGIC_qr
    (Thanks to arc)
  * sort files from all_files_in_dir (GH #28, https://bugs.debian.org/801523
    (Thanks to ntyni)
  * Fix coverity finding in test (GH #25)
    (Thanks to jhi)
  * Add PERL_UNUSED_RESULT and a test (GH #20)
  * Don't redefine MUTABLE_PTR if it's already there (GH #23)
  * Add C_ARRAY_LENGTH and C_ARRAY_END (GH #16)
  * Fix gv_fetchpvn_flags and add init_gv_pvn (#GH 32)
    (Thanks to leont)
  * Fix compiler warnings
    (Thanks to Dave M.)
* Fri Oct  2 2015 coolo@suse.com
- updated to 3.32
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.32 - 2015-09-30
  * Lexical topic no longer works as of perl 5.23
* Mon Apr 13 2015 coolo@suse.com
- updated to 3.31
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.31 - 2015-03-12
  * Regen todo files to sync with blead
  3.30 - 2015-03-05
  * Update typemap to account for STRLEN added in
    3.29, which prevented compiling on older Perls
  3.29 - 2015-03-05
  * Fix issue found by Coverity
    (Thanks to Dave M. for patch)
  3.28 - 2015-01-16
  * Update MANIFEST for regened base/todo files
  3.27 - 2015-01-13
  * Regen base and todo files.
  * Fix isASCII and isCNTRL for <5.6.0
  * Other minor fixups.
    (Thanks to mhx for all of the work on this release)
  3.26 - 2015-01-07
  * Silence some warnings on compilation in perl core
    (Thanks to Dave M. for patches)
  3.25 - 2014-12-02
  * Add caller_cx (works back to Perl 5.6.0)
    (Thanks to Ben Morrow for patch)
  * Silence compiler and coverity warnings
    (Thanks to jhi for patches)
  3.24 - 2014-05-08
  * Remove SvREFCNT_dec_NN until it can be implemented
    properly.
    (Thanks to bulk88 for reporting GH #10)
  * Fix GH #11 - compiler warning under clang
    (Thanks to jhi for reporting it)
  * Fix GH #12 - compiler warnings
    (Thanks to jhi for reporting it)
  3.23 - 2014-04-12
  * Add support for HeUTF8
  * Add GetFileContents() to retrieve the contents of the
    ppport.h file
  * Update MAX_VER to be 5.20
  * Update issue tracker to GitHub
  3.22 - 2014-03-19
  * Add support for the following API
    SvREFCNT_dec_NN
    mg_findext
    sv_unmagicext
  * Update META
    Move bug tracker to github
    Provide link to repository
  * Avoid syntax disallowed by C++11
    (Thanks to Tony C for the patch)
  3.21 - 2013-08-17
  * Fix cpan #87870: Merge core perl commit 90b0dc0e2e
    (Thanks to Father Chrysostomos for the original patch and
    to Steve Hay for forwarding it)
  * Fix cpan #86975: Deterministically order API elements in POD
    (Thanks to Karl Williamson for providing a patch.)
  * Fix cpan #81796: my $_ is deprecated
    (Thanks to Nicholas Clark for providing a patch)
  * Fix cpan #81484: fix isASCII and isCNTRL for inputs > 255
    (Thanks to Karl Williamson for providing a patch)
  * Fix cpan #80314: make use of PERL_NO_GET_CONTEXT the default
  * Fix cpan #79814: Install to 'site' for perl 5.11+
    (Thanks to Robert Sedlacek for providing a patch)
  * Fix cpan #78271: Need SvPV_nomg_nolen
  * Adapt buildperl.pl for newer Perl releases
  * Update masked_versions regex for 5.005 thread builds
  * Some tweaks needed to support 5.003 on 64-bit platforms
* Fri Nov 18 2011 coolo@suse.com
- update to 3.20
  * fix CPAN #56749: isASCII and isCNTRL macros are buggy
    (thanks to Karl Williamson for providing a patch and patiently
    waiting almost two years for me to integrate it)
  * fix CPAN #70427: RealPPPort.xs:1587: error: lvalue required as unary ‘&’ operand
  * keep up with latest core changes
  * fix a warning emitted by the test suite with older perls
  * added support for the following API
    newSVpvs_share
    get_cvn_flags
    get_cvs
  * fix CPAN #50763: mistaken use of $[
    (thanks to Zefram for spotting this)
  * remove spurious PUSHMARK from Perl_ppaddr_t
    (thanks to Gerard Goossen for providing a patch)
  * improved support for newer compilers in buildperl.pl
    (thanks to Philippe Bruhat (BooK) for providing a patch)
  * added support for the following API
    memEQs
    memNEs
  * lots of small toolchain updates
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Dec 26 2009 lars@linux-schulserver.de
- initial version 3.19
